@@ -12,6 +12,7 @@ from flask_appbuilder import (
 from flask import Blueprint, request, jsonify, Response, session
 from flask_appbuilder.views import MultipleView, SimpleFormView, PublicFormView
 import os
+from copy import deepcopy
 
 TEMPLATE_FOLDER = os.path.join(os.path.dirname(__file__), "templates")
 STATIC_FOLDER = os.path.join(os.path.dirname(__file__), "static")
@@ -30,17 +31,27 @@ coreui_bp = Blueprint(
     static_url_path=STATIC_URL_PATH,
 )
 
+extra_args = {
+    'include_sidebar' : True,
+    'include_top_menu': True,
+    'include_top_bar_toggle': True,
+    'include_account_menu': True,
+    'breadcrumbs_submenu': True,
+}
+
 
 class CoreUIBaseView(BaseView):
     template_folder = TEMPLATE_FOLDER
     static_folder = STATIC_FOLDER
     static_url_path = STATIC_URL_PATH
+    extra_args = deepcopy(extra_args)
 
 
 class CoreUIModelView(ModelView):
     template_folder = TEMPLATE_FOLDER
     static_folder = STATIC_FOLDER
     static_url_path = STATIC_URL_PATH
+    extra_args = deepcopy(extra_args)
     form_template = "coreui/general/model/edit.html"
     edit_template = "coreui/general/model/edit.html"
     list_template = "coreui/general/model/list.html"
@@ -52,6 +63,7 @@ class CoreUISimpleFormView(SimpleFormView):
     template_folder = TEMPLATE_FOLDER
     static_folder = STATIC_FOLDER
     static_url_path = STATIC_URL_PATH
+    extra_args = deepcopy(extra_args)
     form_template = "coreui/general/model/edit.html"
 
 
@@ -59,4 +71,5 @@ class CoreUIPublicFormView(PublicFormView):
     template_folder = TEMPLATE_FOLDER
     static_folder = STATIC_FOLDER
     static_url_path = STATIC_URL_PATH
+    extra_args = deepcopy(extra_args)
     form_template = "coreui/general/model/edit.html"
